pub struct DataComponentExactPredicate {
values: Vec<(ComponentEntryRef, ComponentData)>,
}Expand description
Exact component values required by a component matcher.
Fields
values: Vec<(ComponentEntryRef, ComponentData)>Implementations
Sourceimpl DataComponentExactPredicate
impl DataComponentExactPredicate
pub const EMPTY: Self
Sourcepub fn new(values: Vec<(ComponentEntryRef, ComponentData)>) -> Option<Self>
pub fn new(values: Vec<(ComponentEntryRef, ComponentData)>) -> Option<Self>
Creates an exact predicate only when every persistent value can round-trip.
Vanilla’s direct stream codec can admit values rejected by a component’s persistent codec. Steel rejects those here because exact predicates are nested in item components and must not make their containing stack unsavable.
pub fn all_of(components: &DataComponentMap) -> Option<Self>
pub const fn is_empty(&self) -> bool
pub fn values(&self) -> &[(ComponentEntryRef, ComponentData)]
fn from_owned_nbt(tag: &NbtTag) -> Option<Self>
fn to_nbt_value(&self) -> NbtTag